# NaiveChunker

Simple chunker based on sentence count intervals. Useful for testing.

## Usage

```python
--8<-- "sieves/tests/docs/test_preprocessing_usage.py:naive-usage"
```

---

::: sieves.tasks.preprocessing.chunking.naive
